@@ -7,11 +7,14 @@ from typing import Optional
 
 from pydantic import Field
 
-from .contentlines import ParsedProperty
+from .component import ComponentModel
 from .event import Event
+from .freebusy import FreeBusy
+from .journal import Journal
+from .parsing.property import ParsedProperty
 from .timeline import Timeline, calendar_timeline
+from .timezone import Timezone
 from .todo import Todo
-from .types import ComponentModel
 
 _VERSION = metadata.version("ical")
 _PRODID = metadata.metadata("ical")["prodid"]
@@ -25,9 +28,24 @@ class Calendar(ComponentModel):
     prodid: str = Field(default=_PRODID)
     version: str = Field(default=_VERSION)
 
+    #
     # Calendar components
+    #
+
     events: list[Event] = Field(alias="vevent", default_factory=list)
+    """Events associated with this calendar."""
+
     todos: list[Todo] = Field(alias="vtodo", default_factory=list)
+    """Todos associated with this calendar."""
+
+    journal: list[Journal] = Field(alias="vjournal", default_factory=list)
+    """Journals associated with this calendar."""
+
+    freebusy: list[FreeBusy] = Field(alias="vfreebusy", default_factory=list)
+    """Free/busy objects associated with this calendar."""
+
+    timezones: list[Timezone] = Field(alias="vtimezone", default_factory=list)
+    """Timezones associated with this calendar."""
 
     # Unknown or unsupported properties
     extras: list[ParsedProperty] = Field(default_factory=list)
